@@ -377,7 +377,7 @@ class Smart(Generic[T]):
 
     def update_from(
         self,
-        source: Union['Smart', Mapping[str, Any], Sequence[str], Path],
+        source: Union['Smart', Mapping[str, Any], Sequence[str], str, Path],
         name: Optional[str] = None,
         override: bool = True,
         required: bool = True,
@@ -400,12 +400,12 @@ class Smart(Generic[T]):
         smart: Smart
         if isinstance(source, Smart):
             smart = source
+        elif isinstance(source, (str, Path)):
+            smart = Smart(**load_data(Path(source)))
         elif isinstance(source, Mapping):
             smart = Smart(**source)
         elif isinstance(source, Sequence):
             smart = Smart(**dict(map(strutil.parse_param, source)))
-        elif isinstance(source, Path):
-            smart = Smart(**load_data(source))
         else:
             raise TypeError(f"Source type '{type(source)}' is not supported.")
 
@@ -427,7 +427,7 @@ class Smart(Generic[T]):
     @classmethod
     def load_from(
         cls,
-        source: Union['Smart', Mapping[str, Any], Sequence[str], Path],
+        source: Union['Smart', Mapping[str, Any], Sequence[str], str, Path],
         name: Optional[str] = None,
     ) -> Any:
         """Loads object from the given source.
