@@ -3,6 +3,7 @@ from pathlib import Path
 from tempfile import TemporaryDirectory
 from unittest.mock import Mock, patch
 
+from dvc.lock import LockError
 from git import Repo
 
 from smartparams.lab import SmartLab
@@ -156,7 +157,7 @@ class TestRegisterCase(UnitCase):
 
     @patch('smartparams.lab.print')
     def test_wait_on_dvc_lock_release(self, print_mock: Mock) -> None:
-        dvc_repo = Mock(lock=Mock(is_locked=False))
+        dvc_repo = Mock()
 
         self.lab._wait_on_dvc_lock_release(dvc_repo=dvc_repo)
 
@@ -164,7 +165,7 @@ class TestRegisterCase(UnitCase):
 
     @patch('smartparams.lab.print')
     def test_wait_on_dvc_lock_release__locked(self, print_mock: Mock) -> None:
-        dvc_repo = Mock(lock=Mock(is_locked=True))
+        dvc_repo = Mock(lock=Mock(lock=Mock(side_effect=LockError('{}'))))
 
         self.assertRaises(
             TimeoutError,
